.. _sec_tutorial:

########
Tutorial
########

Fast Matrix Algebra with LDGM Precision Matrices
================================================

To run these tutorials, first follow :ref:`the installation instructions <sec_installation>` to clone the repo.

Using LDGMs with real data
--------------------------

To use LDGMs with real data, please consult `ldgm/matlab/tutorials/realdata_tutorial.mlx.`

This MATLAB Live Script shows how to:

1. Load LDGM precision matrices 
2. Merge precision matrices with summary statistics
3. Estimate heritability
4. Compute polygenic scores
5. Perform basic matrix operations
6. Compute likelihood of the summary statistics


Simulating GWAS Summary Stats and running BLUPx
-----------------------------------------------

To use LDGMs to simulate GWAS summary statistics and run BLUPx, please consult: `ldgm/matlab.tutorials/simulations_tutorial.mlx`.

This script shows how to:

1. Load LDGM precision matrices
2. Simulate GWAS summary statistics with realistic LD patterns
3. Run BLUPxldgm on the summary statistics
4. Benchmark BLUPxldgm performance across populations

